@@ -68,6 +68,7 @@ Usage::
         DescribeRouteTablesPaginator,
         DescribeScheduledInstanceAvailabilityPaginator,
         DescribeScheduledInstancesPaginator,
+        DescribeSecurityGroupRulesPaginator,
         DescribeSecurityGroupsPaginator,
         DescribeSnapshotsPaginator,
         DescribeSpotFleetInstancesPaginator,
@@ -241,6 +242,7 @@ Usage::
     describe_route_tables_paginator: DescribeRouteTablesPaginator = client.get_paginator("describe_route_tables")
     describe_scheduled_instance_availability_paginator: DescribeScheduledInstanceAvailabilityPaginator = client.get_paginator("describe_scheduled_instance_availability")
     describe_scheduled_instances_paginator: DescribeScheduledInstancesPaginator = client.get_paginator("describe_scheduled_instances")
+    describe_security_group_rules_paginator: DescribeSecurityGroupRulesPaginator = client.get_paginator("describe_security_group_rules")
     describe_security_groups_paginator: DescribeSecurityGroupsPaginator = client.get_paginator("describe_security_groups")
     describe_snapshots_paginator: DescribeSnapshotsPaginator = client.get_paginator("describe_snapshots")
     describe_spot_fleet_instances_paginator: DescribeSpotFleetInstancesPaginator = client.get_paginator("describe_spot_fleet_instances")
@@ -345,6 +347,7 @@ from .paginator import (
     DescribeRouteTablesPaginator,
     DescribeScheduledInstanceAvailabilityPaginator,
     DescribeScheduledInstancesPaginator,
+    DescribeSecurityGroupRulesPaginator,
     DescribeSecurityGroupsPaginator,
     DescribeSnapshotsPaginator,
     DescribeSpotFleetInstancesPaginator,
@@ -495,6 +498,7 @@ __all__ = (
     "DescribeRouteTablesPaginator",
     "DescribeScheduledInstanceAvailabilityPaginator",
     "DescribeScheduledInstancesPaginator",
+    "DescribeSecurityGroupRulesPaginator",
     "DescribeSecurityGroupsPaginator",
     "DescribeSnapshotsPaginator",
     "DescribeSpotFleetInstancesPaginator",
