@@ -133,6 +133,7 @@ __all__ = (
     "DescribeRouteTablesPaginatorName",
     "DescribeScheduledInstanceAvailabilityPaginatorName",
     "DescribeScheduledInstancesPaginatorName",
+    "DescribeSecurityGroupRulesPaginatorName",
     "DescribeSecurityGroupsPaginatorName",
     "DescribeSnapshotsPaginatorName",
     "DescribeSpotFleetInstancesPaginatorName",
@@ -565,6 +566,7 @@ DescribeScheduledInstanceAvailabilityPaginatorName = Literal[
     "describe_scheduled_instance_availability"
 ]
 DescribeScheduledInstancesPaginatorName = Literal["describe_scheduled_instances"]
+DescribeSecurityGroupRulesPaginatorName = Literal["describe_security_group_rules"]
 DescribeSecurityGroupsPaginatorName = Literal["describe_security_groups"]
 DescribeSnapshotsPaginatorName = Literal["describe_snapshots"]
 DescribeSpotFleetInstancesPaginatorName = Literal["describe_spot_fleet_instances"]
@@ -1264,13 +1266,13 @@ ResourceTypeType = Literal[
     "natgateway",
     "network-acl",
     "network-insights-analysis",
-    "network-insights-boundary",
     "network-insights-path",
     "network-interface",
     "placement-group",
     "reserved-instances",
     "route-table",
     "security-group",
+    "security-group-rule",
     "snapshot",
     "spot-fleet-request",
     "spot-instances-request",
